@@ -42,7 +42,7 @@ KEY_PASSWORD_PREFIX = "571"
 # How long to hold the connection
 # to wait for additional commands for
 # disconnecting the device.
-DISCONNECT_DELAY = 20
+DISCONNECT_DELAY = 12.5
 
 
 class ColorMode(Enum):
@@ -193,7 +193,9 @@ class SwitchbotBaseDevice:
     @property
     def rssi(self) -> int:
         """Return RSSI of device."""
-        return self._get_adv_value("rssi") or self._device.rssi
+        if self._sb_adv_data:
+            return self._sb_adv_data.rssi
+        return self._device.rssi
 
     async def _ensure_connected(self):
         """Ensure connection to device is established."""
